/*
 * Copyright (c) 2019 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string blur: '0'
    property string brightness: '1'
    property string sharpness: '2'
    property string blurblend: '3'
    
    property double blurDefault: 0.500
    property double brightnessDefault: 0.750
    property double sharpnessDefault: 0.850
    property double blurblendDefault: 0.000
    
    property var defaultParameters: [blur, brightness, sharpness, blurblend]
    
    width: 250
    height: 100
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(blur, blurDefault)
            filter.set(brightness, brightnessDefault)
            filter.set(sharpness, sharpnessDefault)
            filter.set(blurblend, blurblendDefault)
            filter.savePreset(preset.defaultParameters)
        }
            setControls()
    }

    function setControls() {
        blurSlider.value = filter.getDouble(blur)
        brightnessSlider.value = filter.getDouble(brightness)
        sharpnessSlider.value = filter.getDouble(sharpness)
        blurblendSlider.value = filter.getDouble(blurblend)
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [blur, brightness, sharpness, blurblend]
            Layout.columnSpan: 2
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('Blur')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: blurSlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.001
            decimals: 3
            //value: filter.getDouble(blur)
            onValueChanged: filter.set(blur, value)
        }
        UndoButton {
            onClicked: blurSlider.value = blurDefault
        }

        Label {
            text: qsTr('Brightness')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: brightnessSlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.001
            decimals: 3
            //value: filter.getDouble(brightness)
            onValueChanged: filter.set(brightness, value)
            }
        UndoButton {
            onClicked: brightnessSlider.value = brightnessDefault
        }

        Label {
            text: qsTr('Sharpness')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: sharpnessSlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.001
            decimals: 3
            //value: filter.getDouble(sharpness)
            onValueChanged: filter.set(sharpness, value)
        }
        UndoButton {
            onClicked: sharpnessSlider.value = sharpnessDefault
        }

        Label {
            text: qsTr('Blurblend')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: blurblendSlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.001
            decimals: 3
            //value: filter.getDouble(blurblend)
            onValueChanged: filter.set(blurblend, value)
        }
        UndoButton {
            onClicked: blurblendSlider.value = blurblendDefault
        }

        Item {
            Layout.fillHeight: true;
        }
    }
    // Connections {
       // target: producer
      //  onPositionChanged: setControls()
    // }
  }
